@@ -13,11 +13,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by the University of
- *      California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -44,7 +40,7 @@ static const char copyright[] =
 "@(#) Copyright (c) 1998\n"
 "Free Software Foundation, Inc.  All rights reserved.\n";
 #endif /* not lint */
-static const char filever[] = "$Id: sccs.c,v 1.41 2004/10/03 10:57:35 james_youngman Exp $";
+static const char filever[] = "$Id: sccs.c,v 1.43 2007/06/21 00:13:55 james_youngman Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -1994,7 +1990,7 @@ unedit (const char *fn)
   myname = username ();
 
   /*
-     **  Copy p-file to temp file, doing deletions as needed.
+   *  Copy p-file to temp file, doing deletions as needed.
    */
 
   while ((pent = getpfent (pfp)) != NULL)
@@ -2002,7 +1998,7 @@ unedit (const char *fn)
       if (strcmp (pent->p_user, myname) == 0)
         {
           /* a match */
-          delete++;
+          delete = TRUE;
         }
       else
         {
@@ -2020,7 +2016,11 @@ unedit (const char *fn)
     {
       extern int errno;
 
-      cp = tail (fn);
+      cp = tail (pfn);
+      if ('p' == cp[0] && '.' == cp[1])
+	{
+	  cp += 2;
+	}
       errno = 0;
       if (access (cp, 0) < 0 && errno != ENOENT)
         goto bad;
@@ -2065,8 +2065,8 @@ unedit (const char *fn)
 
   /* actually remove the g-file */
   
-  /* TODO: %12s in the printfs below is inappropriate
-   * for modern Unix were filenames can be longer than 11 characters...
+  /* TODO: %12s in the printfs below is inappropriate for modern Unix
+   * where filenames can be longer than 11 characters...
    */
   
   if (delete)
